@@ -31,5 +31,10 @@
 
 
 #include <pds/pdsargsfunc.h>
+#include <pds/pdsstring.h>
+#include <pds/pdsfilesfunc.h>
+#include <pds/pdslstring.h>
+#include <pds/pdscstring.h>
+
 
 #endif /* __PDSDATAFUNC_H__ */
